pub struct PixelCache {
pub boxes: Vec<Rectangle>,
}Expand description
A high-performance spatial cache for PixelSet data, organized as a
collection of Rectangle containers.
Overview
PixelCache is designed to store pixels in spatially contiguous boxes
(Rectangle), making it easily to compactly store continuous sets of
pixels.
A PixelCache can be very quickly iterated over, and converted to a
PixelSet, but cannot be directly operated on, and generating one
may take longer.
Fields
boxes: Vec<Rectangle>Implementations